function hfig = plot_manifolds(points, umanif, smanif)

%
% Plot previously calculated stable and unstable manifolds 
% of the given points
%
% points    - cell array of points (2-dim vectors)
% umanif    - cell array of unstable manifolds
% smanif    - cell array of stable manifolds
%
% return values:
% hfig - handle for the figure window
%
% Periodic poitns are plotted with different markers
% according to their stability type: circles for stable
% points, triangles for saddles, diamonds for unstable
% nodes. Point colours correspond to the periods in
% accordance with the colour palette defined in 
% data/bd_colors.mat
% 
%

hfig = figure;
hold on; % plot everything in one figure

for i = 1:length(umanif)
    plot(umanif{i}(:, 1), umanif{i}(:, 2), 'r', 'LineWidth', 2);
end

for i = 1:length(smanif)
    plot(smanif{i}(:, 1), smanif{i}(:, 2), 'b', 'LineWidth', 2);
end

xlim = get(gca, 'XLim');
dx = (xlim(2) - xlim(1))/50;

load('data/bd_colors.mat');
set(gca, 'ColorOrder', contrastmap);

sz = size(points);
for i = 1:sz(1)
    if strcmp(points{i, 3}, 'saddle')
        marker = '^';
    elseif strcmp(points{i, 3}, 'stable')
        marker = 'o';
    else % 'unstable'
        marker = 'd';
    end
    colour = contrastmap(points{i, 2} + 2, :);
    %plot(points{i, 1}(:, 1), points{i, 1}(:, 2), marker, 'MarkerSize', 8, ...
    %     'MarkerEdgeColor', 'k', 'MarkerFaceColor', colour);
    plot(points{i, 1}(:, 1), points{i, 1}(:, 2), marker, 'MarkerSize', 8, ...
         'MarkerEdgeColor', colour);
end

if ((nargin > 3) && (varargin{1}))
    for i = 1:sz(1)
        text(points{i, 1}(:, 1) + dx, points{i, 1}(:, 2), num2str(points{i, 2}), ...
             'HorizontalAlignment', 'left', 'FontSize', 12, 'FontWeight', 'bold');
    end
end

hold off;



