function J = calc_jacob_cyc(fhandle, x, period, dx, varargin)

%
% Calculate jacobian of a cycle with the defined period
% 
% fhandle  - function (dynamical system) handle
% x        - cycle point
% period   - cycle period
% dx       - discretization step (if there is a defined
%            jacobian function in the form of fhandle_J,
%            then this parameter is ignored)
% varargin - cell array of the function parameters
%



% checking if there exists an explicit Jacobi matrix function
fh = functions(fhandle);
Jname = [fh.function '_J'];
Jhandle = str2func(Jname);
Jh = functions(Jhandle);
if strcmp(Jh.file, '')   % there is no file with Jacobi matrix function
    %cprintf(get_colour('warn'), 'The Jacobi matrix is not implemented explicitly.\n');
    %cprintf(get_colour('warn'), 'Calculating Jacobian approximately.\n');
    printf('The Jacobi matrix is not implemented explicitly.\n');
    printf('Calculating Jacobian approximately.\n');
    has_jacob = false;
    J = jacob(fhandle, x, dx, varargin{:});
else
    has_jacob = true;
    J = Jhandle(x, varargin{:});
end

for i = 2:period
   x = fhandle(x, varargin{:});
   if (has_jacob)
       J = Jhandle(x, varargin{:})*J; 
   else
       J = jacob(fhandle, x, dx, varargin{:})*J; 
   end
end

