function i_found = find_segment(fhandle, iters, p, i_cur, Dk, diverge, varargin)

%
% Find the segment on which lies preimage of the next
% searched point 
%
% fhandle  - function (dynamical system) handle
% iters    - number of iterates needed
% p        - array of manifold approximation
% i_cur    - current segment, containing preimage of the
%            last computed point  
% Dk       - current step size
% varargin - cell array of the function parameters
%
% return value:
% i_found - index of the found segment end point
%


k = length(p);
pk = p(end, :);
i_found = i_cur;
dist = 0;

while (i_found <= k)
    pi_img = iterate(fhandle, p(i_found, :), iters, diverge, varargin{:});
    dist = norm(pi_img - pk);
    if (dist > Dk)
        break;
    end;
    
    i_found = i_found + 1;
end;
